[![PyPI version](https://badge.fury.io/py/graphenv.svg)](https://badge.fury.io/py/graphenv)

# graph-env

Start of a code refactor for reinforcement learning on graph search spaces

## Documentation

The documentation is hosted on [GitHub Pages](https://nrel.github.io/graph-env/)
